==> aliyun-python-sdk-polardb-1.8.17.tar.gz: aliyun-python-sdk-polardb-1.8.17/aliyunsdkpolardb/request/v20170801/RefreshProxyLevelRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkpolardb.endpoint import endpoint_data

class RefreshProxyLevelRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'polardb', '2017-08-01', 'RefreshProxyLevel','polardb')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ResourceOwnerId(self):
		return self.get_query_params().get('ResourceOwnerId')

	def set_ResourceOwnerId(self,ResourceOwnerId):
		self.add_query_param('ResourceOwnerId',ResourceOwnerId)

	def get_PlannedEndTime(self):
		return self.get_query_params().get('PlannedEndTime')

	def set_PlannedEndTime(self,PlannedEndTime):
		self.add_query_param('PlannedEndTime',PlannedEndTime)

	def get_ProxyTargetClass(self):
		return self.get_query_params().get('ProxyTargetClass')

	def set_ProxyTargetClass(self,ProxyTargetClass):
		self.add_query_param('ProxyTargetClass',ProxyTargetClass)

	def get_ResourceOwnerAccount(self):
		return self.get_query_params().get('ResourceOwnerAccount')

	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)

	def get_DBClusterId(self):
		return self.get_query_params().get('DBClusterId')

	def set_DBClusterId(self,DBClusterId):
		self.add_query_param('DBClusterId',DBClusterId)

	def get_OwnerAccount(self):
		return self.get_query_params().get('OwnerAccount')

	def set_OwnerAccount(self,OwnerAccount):
		self.add_query_param('OwnerAccount',OwnerAccount)

	def get_OwnerId(self):
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self,OwnerId):
		self.add_query_param('OwnerId',OwnerId)

	def get_PlannedStartTime(self):
		return self.get_query_params().get('PlannedStartTime')

	def set_PlannedStartTime(self,PlannedStartTime):
		self.add_query_param('PlannedStartTime',PlannedStartTime)

	def get_FromTimeService(self):
		return self.get_query_params().get('FromTimeService')

	def set_FromTimeService(self,FromTimeService):
		self.add_query_param('FromTimeService',FromTimeService)

==> aliyun-python-sdk-polardb-1.8.23.tar.gz: aliyun-python-sdk-polardb-1.8.23/aliyunsdkpolardb/request/v20170801/RefreshProxyLevelRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkpolardb.endpoint import endpoint_data

class RefreshProxyLevelRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'polardb', '2017-08-01', 'RefreshProxyLevel','polardb')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ResourceOwnerId(self):
		return self.get_query_params().get('ResourceOwnerId')

	def set_ResourceOwnerId(self,ResourceOwnerId):
		self.add_query_param('ResourceOwnerId',ResourceOwnerId)

	def get_PlannedEndTime(self):
		return self.get_query_params().get('PlannedEndTime')

	def set_PlannedEndTime(self,PlannedEndTime):
		self.add_query_param('PlannedEndTime',PlannedEndTime)

	def get_ResourceGroupId(self):
		return self.get_query_params().get('ResourceGroupId')

	def set_ResourceGroupId(self,ResourceGroupId):
		self.add_query_param('ResourceGroupId',ResourceGroupId)

	def get_ProxyTargetClass(self):
		return self.get_query_params().get('ProxyTargetClass')

	def set_ProxyTargetClass(self,ProxyTargetClass):
		self.add_query_param('ProxyTargetClass',ProxyTargetClass)

	def get_ResourceOwnerAccount(self):
		return self.get_query_params().get('ResourceOwnerAccount')

	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)

	def get_DBClusterId(self):
		return self.get_query_params().get('DBClusterId')

	def set_DBClusterId(self,DBClusterId):
		self.add_query_param('DBClusterId',DBClusterId)

	def get_OwnerAccount(self):
		return self.get_query_params().get('OwnerAccount')

	def set_OwnerAccount(self,OwnerAccount):
		self.add_query_param('OwnerAccount',OwnerAccount)

	def get_OwnerId(self):
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self,OwnerId):
		self.add_query_param('OwnerId',OwnerId)

	def get_PlannedStartTime(self):
		return self.get_query_params().get('PlannedStartTime')

	def set_PlannedStartTime(self,PlannedStartTime):
		self.add_query_param('PlannedStartTime',PlannedStartTime)

	def get_FromTimeService(self):
		return self.get_query_params().get('FromTimeService')

	def set_FromTimeService(self,FromTimeService):
		self.add_query_param('FromTimeService',FromTimeService)
